==> alfred-ui-native-components-0.0.67.tgz: package/ui/templates/onBoarding/index.tsx <==
import React, { FC } from 'react';
import { TouchableHighlight, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { HeadingMediumText, HeadingSmallText, RoundCornersPicture } from '../../atoms';
import { styles } from './styles';
import { ProgressBarHeaderModel } from '../../organisms/progressBarTimer/progressBarTimerModels';

interface Props {
  imageURL: string;
  HeaderProgressBarComponent: any;
  gradientColorList?: string[];
  title?: string;
  description?: string;
  forceCleanInterval?: boolean;
  onNext?: () => void;
}

export const OnBoardingTemplate: FC<Props> = ({
  HeaderProgressBarComponent,
  imageURL,
  gradientColorList= ['#765ACF', '#E4605A'],
  title,
  description,
  onNext,
  forceCleanInterval= false,
}) => {
  const onNextStep = () => {
    !forceCleanInterval && onNext && onNext();
  };

  return (
    <TouchableHighlight onPress={onNext}>
      <LinearGradient colors={gradientColorList} style={styles.onBoardingTemplate}>
        <View style={styles.onBoardingTemplateProgress}>
          <HeaderProgressBarComponent onFinish={onNextStep} forceCleanInterval={forceCleanInterval} />
        </View>
        <View>
          <View style={styles.onBoardingTemplateTitle}>
            <HeadingMediumText numberOfLines={1} color={styles.onBoardingTemplateTitle.color}>
              {title}
            </HeadingMediumText>
          </View>
          <View>
            <HeadingSmallText numberOfLines={3} color={styles.onBoardingTemplateDescription.color}>
              {description}
            </HeadingSmallText>
          </View>
        </View>
        <View style={styles.onBoardingTemplateImageContainer}>
          <RoundCornersPicture width={248} height={340} imageURL={imageURL} />
        </View>
      </LinearGradient>
    </TouchableHighlight>

  );
};

==> alfred-ui-native-components-0.0.68.tgz: package/ui/templates/onBoarding/index.tsx <==
import React, { FC } from 'react';
import { TouchableHighlight, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { HeadingMediumText, HeadingSmallText, RoundCornersPicture } from '../../atoms';
import { styles } from './styles';
import { ProgressBarDynamicHeader } from '../../organisms/progessBarDynamicHeader';

interface Props {
  imageURL: string;
  gradientColorList?: string[];
  title?: string;
  description?: string;
  forceCleanInterval?: boolean;
  onNext?: () => void;
  iterationsLength: number;
  positionPage: number;
}

export const OnBoardingTemplate: FC<Props> = ({
  imageURL,
  gradientColorList= ['#765ACF', '#E4605A'],
  title,
  description,
  onNext,
  forceCleanInterval= false,
  iterationsLength,
  positionPage,
}) => {
  const onNextStep = () => {
    !forceCleanInterval && onNext && onNext();
  };

  return (
    <TouchableHighlight onPress={onNext}>
      <LinearGradient colors={gradientColorList} style={styles.onBoardingTemplate}>
        <View style={styles.onBoardingTemplateProgress}>
          <ProgressBarDynamicHeader
            onFinish={onNextStep}
            forceCleanInterval={forceCleanInterval}
            iterationsLength={iterationsLength}
            positionPage={positionPage}
          />
        </View>
        <View>
          <View style={styles.onBoardingTemplateTitle}>
            <HeadingMediumText numberOfLines={1} color={styles.onBoardingTemplateTitle.color}>
              {title}
            </HeadingMediumText>
          </View>
          <View>
            <HeadingSmallText numberOfLines={3} color={styles.onBoardingTemplateDescription.color}>
              {description}
            </HeadingSmallText>
          </View>
        </View>
        <View style={styles.onBoardingTemplateImageContainer}>
          <RoundCornersPicture width={248} height={340} imageURL={imageURL} />
        </View>
      </LinearGradient>
    </TouchableHighlight>

  );
};
